"""Module that defines the psycopg2_decorator.
"""
import psycopg2

class psql_insert:
    def __init__(self, dsn, table, columns):
        self.table = table
        self.dsn = dsn
        with psycopg2.connect(**dsn) as conn:
            with conn.cursor() as c:
                c.execute(f"DROP TABLE if exists {table};")
                
                # form table with columns
                start = f"CREATE TABLE {table} ("
                mid = ''.join([f"{x[0]} {x[1]}," for x in columns])[:-1]
                end = ");"
                full = start + mid + end
                c.execute(full)

    def __call__(self, func):
        def wrapper(*args, **kwargs):
            result = func(*args, **kwargs)
            self.insert(result)
            return result
        return wrapper

    def insert(self, result):
        with psycopg2.connect(**self.dsn) as conn:
            with conn.cursor() as c:
                start = f"INSERT INTO {self.table} VALUES ("
                mid = ''.join([f"{x} ," for x in result])[:-1]
                end = ");"
                full = start + mid + end
                c.execute(full)



import os
from gerardo import psql_insert

pghost = os.environ["PGHOST"]
DSN = {
    "host": pghost,
    "port": "",
    "user": "",
    "password": "",
    "dbname": "test_temp",
}
PSQL_TABLE = "test_table"
COLUMNS = [('x', 'INT'), ('x2', 'INT')]

@psql_insert(DSN, PSQL_TABLE, COLUMNS)
def f(x):
    return (x, x**2)

[f(x) for x in range(100)]



"""A setuptools based setup module.
"""

from os import path

from setuptools import setup

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, "README.md"), encoding="utf-8") as f:
    long_description = f.read()

with open(path.join(here, "gerardo", "__version__.py")) as f:
    version = f.read().split('"')[1]

setup(
    name="gerardo",
    version=version,
    description="Simple decorator for multiprocessing and psql insertion",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/kevinywlui/gerardo",
    author="kevin lui",
    author_email="kevinywlui@gmail.com",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
    keywords="psql multiprocessing",
    packages=["gerardo"],
    install_requires=["psycopg2-binary"],
)
